==> dxgl-src-0.4.0.zip: ddraw/glRenderWindow.h <==
// DXGL
// Copyright (C) 2012 William Feely

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

#pragma once
#ifndef _GLRENDERWINDOW_H
#define _GLRENDERWINDOW_H

LRESULT CALLBACK RenderWndProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam);

class glDirectDraw7;
void WaitForObjectAndMessages(HANDLE object);
class glRenderWindow
{
public:
	glRenderWindow(int width, int height, bool fullscreen, HWND parent, glDirectDraw7 *glDD7);
	~glRenderWindow();
	void resize(int width, int height);
	HWND GetHWnd(){return hWnd;};
	LRESULT WndProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam);
	static DWORD WINAPI ThreadEntry(void *entry);
private:
	DWORD _Entry();
	HWND hWnd;
	HWND hParentWnd;
	HANDLE hThread;
	HANDLE ReadyEvent;
	int width;
	int height;
	bool fullscreen;
	bool dead;
	glDirectDraw7 *ddInterface;
};


#endif //_GLRENDERWINDOW_H

==> dxgl-src-0.5.5.zip: ddraw/glRenderWindow.h <==
// DXGL
// Copyright (C) 2012 William Feely

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

#pragma once
#ifndef _GLRENDERWINDOW_H
#define _GLRENDERWINDOW_H

LRESULT CALLBACK RenderWndProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam);

class glDirectDraw7;
void WaitForObjectAndMessages(HANDLE object);
class glRenderWindow
{
public:
	glRenderWindow(int width, int height, bool fullscreen, HWND parent, glDirectDraw7 *glDD7, bool devwnd);
	~glRenderWindow();
	void resize(int width, int height);
	HWND GetHWnd(){return hWnd;};
	LRESULT WndProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam);
	static DWORD WINAPI ThreadEntry(void *entry);
private:
	DWORD _Entry();
	HWND hWnd;
	HWND hParentWnd;
	HANDLE hThread;
	HANDLE ReadyEvent;
	int width;
	int height;
	bool fullscreen;
	bool dead;
	bool device;
	glDirectDraw7 *ddInterface;
};


#endif //_GLRENDERWINDOW_H
